# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2010 Nexedi SARL and Contributors. All Rights Reserved.
# Copyright (c) 2006-2008 Zope Corporation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
import os, shutil
import pkg_resources
import plone.recipe.zope2instance
from plone.recipe.zope2instance import make

class Recipe(plone.recipe.zope2instance.Recipe):
    def install(self, update=False):
        # Override plone.recipe.zope2instance so as to prepare several
        # directories used by ERP5.
        options = self.options
        location = options['location']

        if not update:
            if os.path.exists(location):
                shutil.rmtree(location)

            # Which Zope2 version do we have?
            dist = pkg_resources.get_distribution('Zope2')
            parsed = dist.parsed_version
            major, minor = parsed[0:2]
            major, minor = int(major), int(minor)
            # We only support creating instances for 2.12 and 2.13
            if minor > 13:
                minor = 13
            version = str(major) + str(minor)
            make.make_instance(options.get('user', None), location, version)

        # patch begin: create several directories and symlinks for ERP5
        base_dir = self.buildout['buildout']['directory']
        var_dir = options.get('var', os.path.join(base_dir, 'var'))
        if not os.path.exists(var_dir):
            os.mkdir(var_dir)
        for directory in ('Constraint', 'Document', 'Extensions',
                          'Products', 'PropertySheet', 'tests'):
            real_path = os.path.join(var_dir, directory)
            if not os.path.exists(real_path):
                os.mkdir(real_path)
            link_path = os.path.join(location, directory)
            if os.path.exists(link_path) and not os.path.islink(link_path):
                shutil.rmtree(link_path)
            if not os.path.exists(link_path):
                os.symlink(real_path, link_path)
        for directory in ('bt5',):
            real_path = os.path.join(location, '..', directory)
            if not os.path.exists(real_path):
                os.mkdir(real_path)
            path = os.path.join(location, directory)
            if os.path.exists(path) and not os.path.islink(path):
                shutil.rmtree(path)
            if not os.path.exists(path):
                os.symlink(real_path, path)
        # patch end: create several directories and symlinks for ERP5

        try:
            # Make a new zope.conf based on options in buildout.cfg
            self.build_zope_conf()

            # Install extra scripts
            self.install_scripts()

            # Add zcml files to package-includes
            self.build_package_includes()
        except:
            # clean up
            if os.path.exists(location):
                shutil.rmtree(location)
            raise

        return location
